@@ -2,6 +2,7 @@ var concat = require('../')
 var test = require('tape')
 var TA = require('typedarray')
 var U8 = typeof Uint8Array !== 'undefined' ? Uint8Array : TA.Uint8Array
+var bufferFrom = require('buffer-from')
 
 test('buffer stream', function (t) {
   t.plan(2)
@@ -9,8 +10,8 @@ test('buffer stream', function (t) {
     t.ok(Buffer.isBuffer(out))
     t.equal(out.toString('utf8'), 'pizza Array is not a stringy cat')
   })
-  buffers.write(new Buffer('pizza Array is not a ', 'utf8'))
-  buffers.write(new Buffer('stringy cat'))
+  buffers.write(bufferFrom('pizza Array is not a ', 'utf8'))
+  buffers.write(bufferFrom('stringy cat'))
   buffers.end()
 })
 
@@ -20,7 +21,7 @@ test('buffer mixed writes', function (t) {
     t.ok(Buffer.isBuffer(out))
     t.equal(out.toString('utf8'), 'pizza Array is not a stringy cat555')
   })
-  buffers.write(new Buffer('pizza'))
+  buffers.write(bufferFrom('pizza'))
   buffers.write(' Array is not a ')
   buffers.write([ 115, 116, 114, 105, 110, 103, 121 ])
   var u8 = new U8(4)
